@@ -1,4 +1,4 @@
-## Copyright (C) 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -36,8 +36,8 @@ function sys = __set__ (sys, prop, val)
       sys.w = val;
 
     otherwise
-      error ("frd: set: invalid property name");
+      error ("frd: set: invalid property name '%s'", prop);
 
   endswitch
 
-endfunction
\ No newline at end of file
+endfunction
