@@ -1,4 +1,4 @@
-## Copyright (C) 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -26,8 +26,8 @@
 
 function sys = __sys_prune__ (sys, out_idx, in_idx, w_idx = ":")
 
-  sys.lti = __lti_prune__ (sys.lti, out_idx, in_idx);
+  [sys.lti, out_idx, in_idx] = __lti_prune__ (sys.lti, out_idx, in_idx);
 
   sys.H = sys.H(out_idx, in_idx, w_idx);
 
-endfunction
\ No newline at end of file
+endfunction
