@@ -1,4 +1,4 @@
-## Copyright (C) 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -22,8 +22,8 @@
 ## Created: October 2010
 ## Version: 0.1
 
-function [zer, gain] = __zero__ (sys)
+function [zer, gain, info] = __zero__ (sys)
 
   error ("frd: zero: this is not possible");
 
-endfunction
\ No newline at end of file
+endfunction
