@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -25,7 +25,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI model to be converted to frequency response data.
+## @acronym{LTI} model to be converted to frequency response data.
 ## If second argument @var{w} is omitted, the interesting
 ## frequency range is calculated by the zeros and poles of @var{sys}.
 ## @item H
@@ -70,6 +70,16 @@
 ## Cell vector of length p containing strings.
 ## Default names are @code{@{'y1', 'y2', ...@}}
 ##
+## @item 'ingroup'
+## Struct with input group names as field names and
+## vectors of input indices as field values.
+## Default is an empty struct.
+##
+## @item 'outgroup'
+## Struct with output group names as field names and
+## vectors of output indices as field values.
+## Default is an empty struct.
+##
 ## @item 'name'
 ## String containing the name of the model.
 ##
