@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -17,7 +17,7 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{sys} =} blkdiag (@var{sys1}, @var{sys2})
-## Block-diagonal concatenation of LTI models.
+## Block-diagonal concatenation of @acronym{LTI} models.
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -28,4 +28,4 @@ function sys = blkdiag (varargin)
 
   sys = append (varargin{:});
 
-endfunction
\ No newline at end of file
+endfunction
