@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -17,12 +17,12 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{k} =} dcgain (@var{sys})
-## DC gain of LTI model.
+## DC gain of @acronym{LTI} model.
 ##
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI system.
+## @acronym{LTI} system.
 ## @end table
 ##
 ## @strong{Outputs}
@@ -47,4 +47,4 @@ function gain = dcgain (sys)
 
   gain = __freqresp__ (sys, 0);
 
-endfunction
\ No newline at end of file
+endfunction
