@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -17,7 +17,7 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{p} =} eig (@var{sys})
-## Compute poles of LTI system.
+## Compute poles of @acronym{LTI} system.
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -28,4 +28,4 @@ function pol = eig (varargin)
 
   pol = pole (varargin{:});
 
-endfunction
\ No newline at end of file
+endfunction
