@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -18,7 +18,7 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} get (@var{sys})
 ## @deftypefnx {Function File} {@var{value} =} get (@var{sys}, @var{"property"})
-## Access property values of LTI objects.
+## Access property values of @acronym{LTI} objects.
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -38,10 +38,14 @@ function varargout = get (sys, varargin)
       prop = lower (varargin{k});
 
       switch (prop)
-        case {"inname", "inputname"}
+        case {"inname", "inputname", "inn", "inputn"}
           val = sys.inname;
-        case {"outname", "outputname"}
+        case {"outname", "outputname", "outn", "outputn"}
           val = sys.outname;
+        case {"ingroup", "inputgroup", "ing", "inputg"}
+          val = sys.ingroup;
+        case {"outgroup", "outputgroup", "outg", "outputg"}
+          val = sys.outgroup;
         case {"tsam", "ts"}
           val = sys.tsam;
         case "name"
@@ -58,4 +62,4 @@ function varargout = get (sys, varargin)
     endfor
   endif
 
-endfunction
\ No newline at end of file
+endfunction
