@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -17,7 +17,7 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{bool} =} issiso (@var{sys})
-## Determine whether LTI model is single-input/single-output (SISO).
+## Determine whether @acronym{LTI} model is single-input/single-output (SISO).
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -32,4 +32,4 @@ function bool = issiso (sys)
 
   bool = all (size (sys) == 1);
 
-endfunction
\ No newline at end of file
+endfunction
