@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -18,7 +18,7 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{sys} =} minreal (@var{sys})
 ## @deftypefnx {Function File} {@var{sys} =} minreal (@var{sys}, @var{tol})
-## Minimal realization or zero-pole cancellation of LTI models.
+## Minimal realization or zero-pole cancellation of @acronym{LTI} models.
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
