@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2012   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -19,8 +19,8 @@
 ## @deftypefn {Function File} {} set (@var{sys})
 ## @deftypefnx {Function File} {} set (@var{sys}, @var{"property"}, @var{value}, @dots{})
 ## @deftypefnx {Function File} {@var{retsys} =} set (@var{sys}, @var{"property"}, @var{value}, @dots{})
-## Set or modify properties of LTI objects.
-## If no return argument @var{retsys} is specified, the modified LTI object is stored
+## Set or modify properties of @acronym{LTI} objects.
+## If no return argument @var{retsys} is specified, the modified @acronym{LTI} object is stored
 ## in input argument @var{sys}.  @command{set} can handle multiple properties in one call:
 ## @code{set (sys, 'prop1', val1, 'prop2', val2, 'prop3', val3)}.
 ## @code{set (sys)} prints a list of the object's property names.
@@ -28,7 +28,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.4
+## Version: 0.5
 
 function retsys = set (sys, varargin)
 
@@ -59,21 +59,37 @@ function retsys = set (sys, varargin)
       val = varargin{k+1};
 
       switch (prop)
-        case {"inname", "inputname"}
+        case {"inname", "inputname", "inn", "inputn"}
           sys.inname = __adjust_labels__ (val, m);
 
-        case {"outname", "outputname"}
+        case {"outname", "outputname", "outn", "outputn"}
           sys.outname = __adjust_labels__ (val, p);
 
         case {"tsam", "ts"}
           if (issample (val, -1))
             sys.tsam = val;
-            warning ("lti: set: use the editing of property '%s' with caution", prop);
-            warning ("          it may lead to corrupted models");
+            ## TODO: display hint for 'd2d' to resample model?
           else
             error ("lti: set: invalid sampling time");
           endif
-          ## TODO: use of c2d, d2c and d2d if tsam changes?
+
+        case {"ingroup", "inputgroup", "ing", "inputg"}
+          if (isstruct (val) && all (structfun (@(x) is_group_idx (x, m), val)))
+            empty = structfun (@isempty, val);
+            fields = fieldnames (val);
+            sys.ingroup = rmfield (val, fields(empty));
+          else
+            error ("lti: set: property 'ingroup' requires a struct containing valid input indices in the range [1, %d]", m);
+          endif
+
+        case {"outgroup", "outputgroup", "outg", "outputg"}
+          if (isstruct (val) && all (structfun (@(x) is_group_idx (x, p), val)))
+            empty = structfun (@isempty, val);
+            fields = fieldnames (val);
+            sys.outgroup = rmfield (val, fields(empty));
+          else
+            error ("lti: set: property 'outgroup' requires a struct containing valid output indices in the range [1, %d]", p);
+          endif
 
         case "name"
           if (ischar (val))
@@ -107,4 +123,11 @@ function retsys = set (sys, varargin)
 
   endif
 
-endfunction
\ No newline at end of file
+endfunction
+
+
+function bool = is_group_idx (idx, n)
+
+  bool = (isempty (idx) || (is_real_vector (idx) && all (idx > 0) && all (idx <= n) && all (abs (fix (idx)) == idx)));
+
+endfunction
