@@ -1,4 +1,4 @@
-## Copyright (C) 2012   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -17,7 +17,7 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{bool} =} size_equal (@var{a}, @var{b}, @dots{})
-## Return true if LTI models (and matrices) @var{a}, @var{b}, @dots{}
+## Return true if @acronym{LTI} models (and matrices) @var{a}, @var{b}, @dots{}
 ## are of equal size and false otherwise.
 ## @end deftypefn
 
