@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -24,7 +24,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## Any type of LTI model.
+## Any type of @acronym{LTI} model.
 ## @end table
 ##
 ## @strong{Outputs}
@@ -59,4 +59,4 @@ function [a, b, c, d, tsam, scaled] = ssdata (sys)
 
   tsam = sys.tsam;
 
-endfunction
\ No newline at end of file
+endfunction
