@@ -1,4 +1,4 @@
-## Copyright (C) 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -16,7 +16,7 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## Transpose of LTI objects.  Used by Octave for "sys.'".
+## Transpose of @acronym{LTI} objects.  Used by Octave for "sys.'".
 ## Useful for dual problems, i.e. controllability and observability
 ## or designing estimator gains with @command{lqr} and @command{place}.
 
@@ -37,4 +37,4 @@ function sys = transpose (sys)
   sys.inname = repmat ({""}, p, 1);
   sys.outname = repmat ({""}, m, 1);
 
-endfunction
\ No newline at end of file
+endfunction
