@@ -1,4 +1,4 @@
-## Copyright (C) 2012   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -16,7 +16,7 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## Unary plus of LTI object.  Used by Octave for "+sys".
+## Unary plus of @acronym{LTI} object.  Used by Octave for "+sys".
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: June 2012
