@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -16,13 +16,36 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{sys} =} xperm (@var{sys}, @var{st_idx})
+## @deftypefn {Function File} {@var{retsys} =} xperm (@var{sys}, @var{idx})
 ## Reorder states in state-space models.
+##
+## @strong{Inputs}
+## @table @var
+## @item sys
+## State-space model.
+## @item idx
+## Vector containing the state indices in the desired order.
+## Alternatively, a cell vector containing the state names
+## is possible as well.  See @code{sys.stname}.  State names
+## only work if they were assigned explicitly before, i.e.
+## @code{sys.stname} contains no empty strings.
+## Note that if certain state indices of @var{sys} are
+## missing or appear multiple times in @var{idx}, these
+## states will be pruned or duplicated accordingly in the
+## resulting state-space model @var{retsys}.
+## @end table
+##
+## @strong{Outputs}
+## @table @var
+## @item retsys
+## Resulting state-space model with states reordered according to @var{idx}.
+## @end table
+##
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: November 2009
-## Version: 0.1
+## Version: 0.2
 
 function sys = xperm (sys, st_idx)
 
@@ -30,10 +53,6 @@ function sys = xperm (sys, st_idx)
     print_usage ();
   endif
 
-  if (! is_real_vector (st_idx))
-    error ("xperm: second argument invalid");
-  endif
-
   if (! isa (sys, "ss"))
     warning ("xperm: system not in state-space form");
     sys = ss (sys);
@@ -41,4 +60,4 @@ function sys = xperm (sys, st_idx)
 
   sys = __sys_prune__ (sys, ":", ":", st_idx);
 
-endfunction
\ No newline at end of file
+endfunction
