@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -40,15 +40,15 @@ function val = __get__ (sys, prop)
     case "e"
       val = sys.e;
 
-    case {"stname", "statename"}
+    case {"stname", "statename", "stn", "staten"}
       val = sys.stname;
 
     case "scaled"
       val = sys.scaled;
 
     otherwise
-      error ("ss: get: invalid property name");
+      error ("ss: get: invalid property name '%s'", prop);
 
   endswitch
 
-endfunction
\ No newline at end of file
+endfunction
