@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -20,29 +20,35 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.3
+## Version: 0.4
 
 function [retsys, retlti] = __sys2tf__ (sys)
 
+  sg_flag = false;                              # static gain flag
+
   try
     [a, b, c, d, tsam, scaled] = ssdata (sys);  # system could be a descriptor model
 
-    [num, den, ign, igd, md, p, m] = __sl_tb04bd__ (a, b, c, d, scaled);
+    if (tsam == -2 || isempty (a))              # static gain
+      sg_flag = true;
+    else
+      [num, den, ign, igd, md, p, m] = __sl_tb04bd__ (a, b, c, d, scaled);
 
-    num = reshape (num, md, p, m);
-    den = reshape (den, md, p, m);
+      num = reshape (num, md, p, m);
+      den = reshape (den, md, p, m);
 
-    num = mat2cell (num, md, ones(1,p), ones(1,m));
-    den = mat2cell (den, md, ones(1,p), ones(1,m));
+      num = mat2cell (num, md, ones(1,p), ones(1,m));
+      den = mat2cell (den, md, ones(1,p), ones(1,m));
 
-    num = squeeze (num);
-    den = squeeze (den);
+      num = squeeze (num);
+      den = squeeze (den);
 
-    ign = mat2cell (ign, ones(1,p), ones(1,m));
-    igd = mat2cell (igd, ones(1,p), ones(1,m));
+      ign = mat2cell (ign, ones(1,p), ones(1,m));
+      igd = mat2cell (igd, ones(1,p), ones(1,m));
 
-    num = cellfun (@(x, y) x(1:y+1), num, ign, "uniformoutput", false);
-    den = cellfun (@(x, y) x(1:y+1), den, igd, "uniformoutput", false);
+      num = cellfun (@(x, y) x(1:y+1), num, ign, "uniformoutput", false);
+      den = cellfun (@(x, y) x(1:y+1), den, igd, "uniformoutput", false);
+    endif
   catch
     ## sys.e was probably singular, therefore ssdata failed.
     if (issiso (sys))
@@ -65,10 +71,12 @@ function [retsys, retlti] = __sys2tf__ (sys)
     tsam = get (sys, "tsam");
   end_try_catch
 
-  retsys = tf (num, den, tsam);                 # tsam needed to set appropriate tfvar
+  if (sg_flag)
+    retsys = tf (d);
+  else
+    retsys = tf (num, den, tsam);               # tsam needed to set appropriate tfvar
+  endif
   retlti = sys.lti;                             # preserve lti properties
-  
-  ## FIXME: sys = tf (ss (5))
 
 endfunction
 
