@@ -1,4 +1,4 @@
-## Copyright (C) 2009   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -26,9 +26,9 @@
 
 function sys = __sys_prune__ (sys, out_idx, in_idx)
 
-  sys.lti = __lti_prune__ (sys.lti, out_idx, in_idx);
+  [sys.lti, out_idx, in_idx] = __lti_prune__ (sys.lti, out_idx, in_idx);
 
   sys.num = sys.num(out_idx, in_idx);
   sys.den = sys.den(out_idx, in_idx);
 
-endfunction
\ No newline at end of file
+endfunction
