@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2011, 2012   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -26,7 +26,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI model to be converted to transfer function.
+## @acronym{LTI} model to be converted to transfer function.
 ## @item num
 ## Numerator or cell of numerators.  Each numerator must be a row vector
 ## containing the coefficients of the polynomial in descending powers of
@@ -80,6 +80,16 @@
 ## Cell vector of length p containing strings.
 ## Default names are @code{@{'y1', 'y2', ...@}}
 ##
+## @item 'ingroup'
+## Struct with input group names as field names and
+## vectors of input indices as field values.
+## Default is an empty struct.
+##
+## @item 'outgroup'
+## Struct with output group names as field names and
+## vectors of output indices as field values.
+## Default is an empty struct.
+##
 ## @item 'name'
 ## String containing the name of the model.
 ##
@@ -253,4 +263,3 @@ function sys = tf (num = {}, den = {}, varargin)
   endif
 
 endfunction
-
