@@ -1,6 +1,6 @@
 ## Copyright (C) 1996, 2000, 2004, 2005, 2006, 2007
 ##               Auburn University. All rights reserved.
-## Copyright (C) 2009 - 2012   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This program is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
@@ -79,7 +79,7 @@ function w = __frequency_vector__ (sys_cell, wbounds = "std", wmin, wmax)
       dec_max = repmat ({log10 (wmax)}, 1, len);
     endif
 
-    idx = cellfun (@(zp, dec_min, dec_max) find (zp > 10^dec_min & zp < 10^dec_max), \
+    idx = cellfun (@(zp, dec_min, dec_max) find (zp > 10^dec_min & zp < 10^dec_max), ...
                    zp, dec_min, dec_max, "uniformoutput", false);
     zp = cellfun (@(zp, idx) zp(idx), zp, idx, "uniformoutput", false);
 
