@@ -1,4 +1,4 @@
-## Copyright (C) 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -159,10 +159,10 @@ function [Gr, info] = __modred_ab09id__ (method, varargin)
   
   
   ## perform model order reduction
-  [ar, br, cr, dr, nr, hsv, ns] = __sl_ab09id__ (a, b, c, d, dt, equil, nr, ordsel, alpha, job, \
-                                            av, bv, cv, dv, \
-                                            aw, bw, cw, dw, \
-                                            weight, jobc, jobo, alphac, alphao, \
+  [ar, br, cr, dr, nr, hsv, ns] = __sl_ab09id__ (a, b, c, d, dt, equil, nr, ordsel, alpha, job, ...
+                                            av, bv, cv, dv, ...
+                                            aw, bw, cw, dw, ...
+                                            weight, jobc, jobo, alphac, alphao, ...
                                             tol1, tol2);
 
   ## assemble reduced order model
@@ -172,7 +172,3 @@ function [Gr, info] = __modred_ab09id__ (method, varargin)
   info = struct ("nr", nr, "ns", ns, "hsv", hsv);
 
 endfunction
-
-
-
-
