@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -23,20 +23,20 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item G
-## LTI model of plant.
+## @acronym{LTI} model of plant.
 ## @item W1
-## LTI model of performance weight.  Bounds the largest singular values of sensitivity @var{S}.
+## @acronym{LTI} model of performance weight.  Bounds the largest singular values of sensitivity @var{S}.
 ## Model must be empty @code{[]}, SISO or of appropriate size.
 ## @item W2
-## LTI model to penalize large control inputs.  Bounds the largest singular values of @var{KS}.
+## @acronym{LTI} model to penalize large control inputs.  Bounds the largest singular values of @var{KS}.
 ## Model must be empty @code{[]}, SISO or of appropriate size.
 ## @item W3
-## LTI model of robustness and noise sensitivity weight.  Bounds the largest singular values of 
+## @acronym{LTI} model of robustness and noise sensitivity weight.  Bounds the largest singular values of 
 ## complementary sensitivity @var{T}.  Model must be empty @code{[]}, SISO or of appropriate size.
 ## @end table
 ##
 ## All inputs must be proper/realizable.
-## Scalars, vectors and matrices are possible instead of LTI models.
+## Scalars, vectors and matrices are possible instead of @acronym{LTI} models.
 ##
 ## @strong{Outputs}
 ## @table @var
@@ -104,7 +104,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: December 2009
-## Version: 0.2
+## Version: 0.3
 
 function P = augw (G, W1 = [], W2 = [], W3 = [])
 
@@ -141,6 +141,8 @@ function P = augw (G, W1 = [], W2 = [], W3 = [])
 
   P = append (W1, W2, W3, eye (p, p)) * [Pr, Pu];
 
+  P = mktito (P, p, m);
+
 endfunction
 
 
