@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -105,39 +105,39 @@ function [x, l, g] = dare (a, b, q, r, s = [], e = [])
 
   if (! is_real_square_matrix (a, q, r))
     ## error ("dare: a, q, r must be real and square");
-    error ("dare: %s, %s, %s must be real and square", \
+    error ("dare: %s, %s, %s must be real and square", ...
             inputname (1), inputname (3), inputname (4));
   endif
   
   if (! is_real_matrix (b) || rows (a) != rows (b))
     ## error ("dare: a and b must have the same number of rows");
-    error ("dare: %s and %s must have the same number of rows", \
+    error ("dare: %s and %s must have the same number of rows", ...
             inputname (1), inputname (2));
   endif
   
   if (columns (r) != columns (b))
     ## error ("dare: b and r must have the same number of columns");
-    error ("dare: %s and %s must have the same number of columns", \
+    error ("dare: %s and %s must have the same number of columns", ...
             inputname (2), inputname (4));
   endif
 
   if (! is_real_matrix (s) && ! size_equal (s, b))
     ## error ("dare: s(%dx%d) must be real and identically dimensioned with b(%dx%d)",
     ##         rows (s), columns (s), rows (b), columns (b));
-    error ("dare: %s(%dx%d) must be real and identically dimensioned with %s(%dx%d)", \
+    error ("dare: %s(%dx%d) must be real and identically dimensioned with %s(%dx%d)", ...
             inputname (5), rows (s), columns (s), inputname (2), rows (b), columns (b));
   endif
 
   if (! isempty (e) && (! is_real_square_matrix (e) || ! size_equal (e, a)))
     ## error ("dare: a and e must have the same number of rows");
-    error ("dare: %s and %s must have the same number of rows", \
+    error ("dare: %s and %s must have the same number of rows", ...
             inputname (1), inputname (6));
   endif
 
   ## check stabilizability
   if (! isstabilizable (a, b, e, [], 1))
     ## error ("dare: (a, b) not stabilizable");
-    error ("dare: (%s, %s) not stabilizable", \
+    error ("dare: (%s, %s) not stabilizable", ...
             inputname (1), inputname (2));
   endif
 
@@ -152,7 +152,7 @@ function [x, l, g] = dare (a, b, q, r, s = [], e = [])
 
   if (isdefinite (m) < 0)
     ## error ("dare: require [q, s; s.', r] >= 0");
-    error ("dare: require [%s, %s; %s.', %s] >= 0", \
+    error ("dare: require [%s, %s; %s.', %s] >= 0", ...
             inputname (3), inputname (5), inputname (5), inputname (4));
   endif
 
