@@ -1,4 +1,4 @@
-## Copyright (C) 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -52,13 +52,13 @@ function [x, scale] = dlyap (a, b, c, e)
 
       if (! is_real_square_matrix (a, b))
         ## error ("dlyap: a, b must be real and square");
-        error ("dlyap: %s, %s must be real and square", \
+        error ("dlyap: %s, %s must be real and square", ...
                 inputname (1), inputname (2));
       endif
   
       if (rows (a) != rows (b))
         ## error ("dlyap: a, b must have the same number of rows");
-        error ("dlyap: %s, %s must have the same number of rows", \
+        error ("dlyap: %s, %s must have the same number of rows", ...
                 inputname (1), inputname (2));
       endif
 
@@ -70,13 +70,13 @@ function [x, scale] = dlyap (a, b, c, e)
   
       if (! is_real_square_matrix (a, b))
         ## error ("dlyap: a, b must be real and square");
-        error ("dlyap: %s, %s must be real and square", \
+        error ("dlyap: %s, %s must be real and square", ...
                 inputname (1), inputname (2));
       endif
 
       if (! is_real_matrix (c) || rows (c) != rows (a) || columns (c) != columns (b))
         ## error ("dlyap: c must be a real (%dx%d) matrix", rows (a), columns (b));
-        error ("dlyap: %s must be a real (%dx%d) matrix", \
+        error ("dlyap: %s must be a real (%dx%d) matrix", ...
                 rows (a), columns (b), inputname (3));
       endif
 
@@ -90,19 +90,19 @@ function [x, scale] = dlyap (a, b, c, e)
       
       if (! is_real_square_matrix (a, b, e))
         ## error ("dlyap: a, b, e must be real and square");
-        error ("dlyap: %s, %s, %s must be real and square", \
+        error ("dlyap: %s, %s, %s must be real and square", ...
                 inputname (1), inputname (2), inputname (4));
       endif
       
       if (rows (b) != rows (a) || rows (e) != rows (a))
         ## error ("dlyap: a, b, e must have the same number of rows");
-        error ("dlyap: %s, %s, %s must have the same number of rows", \
+        error ("dlyap: %s, %s, %s must have the same number of rows", ...
                 inputname (1), inputname (2), inputname (4));
       endif
       
       if (! issymmetric (b))
         ## error ("dlyap: b must be symmetric");
-        error ("dlyap: %s must be symmetric", \
+        error ("dlyap: %s must be symmetric", ...
                 inputname (2));
       endif
 
@@ -163,4 +163,4 @@ endfunction
 %!assert (X, X_exp, 1e-4);
 
 ## Generalized Lyapunov
-## TODO: add a test
\ No newline at end of file
+## TODO: add a test
