@@ -1,4 +1,4 @@
-## Copyright (C) 2012   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -73,6 +73,16 @@
 ## Cell vector of length p containing strings.
 ## Default names are @code{@{'y1', 'y2', ...@}}
 ##
+## @item 'ingroup'
+## Struct with input group names as field names and
+## vectors of input indices as field values.
+## Default is an empty struct.
+##
+## @item 'outgroup'
+## Struct with output group names as field names and
+## vectors of output indices as field values.
+## Default is an empty struct.
+##
 ## @item 'name'
 ## String containing the name of the model.
 ##
@@ -162,6 +172,7 @@ function sys = filt (num = {}, den = {}, tsam = -1, varargin)
 
 endfunction
 
+
 %!shared num, den, n1, d1, n2, d2, n2e, d2e
 %! num = [0, 3];
 %! den = [1, 4, 2];
