@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2013   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -16,13 +16,16 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn{Function File} {[@var{K}, @var{N}, @var{info}] =} h2syn (@var{P}, @var{nmeas}, @var{ncon})
-## H-2 control synthesis for LTI plant.
+## @deftypefn{Function File} {[@var{K}, @var{N}, @var{gamma}, @var{info}] =} h2syn (@var{P}, @var{nmeas}, @var{ncon})
+## @deftypefnx{Function File} {[@var{K}, @var{N}, @var{gamma}, @var{info}] =} h2syn (@var{P})
+## H-2 control synthesis for @acronym{LTI} plant.
 ##
 ## @strong{Inputs}
 ## @table @var
 ## @item P
-## Generalized plant.  Must be a proper/realizable LTI model.
+## Generalized plant.  Must be a proper/realizable @acronym{LTI} model.
+## If @var{P} is constructed with @command{mktito} or @command{augw},
+## arguments @var{nmeas} and @var{ncon} can be omitted.
 ## @item nmeas
 ## Number of measured outputs v.  The last @var{nmeas} outputs of @var{P} are connected to the
 ## inputs of controller @var{K}.  The remaining outputs z (indices 1 to p-nmeas) are used
@@ -84,12 +87,12 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: December 2009
-## Version: 0.2
+## Version: 0.3
 
 function [K, varargout] = h2syn (P, nmeas, ncon)
 
   ## check input arguments
-  if (nargin != 3)
+  if (nargin != 1 && nargin != 3)
     print_usage ();
   endif
   
@@ -97,12 +100,16 @@ function [K, varargout] = h2syn (P, nmeas, ncon)
     error ("h2syn: first argument must be an LTI system");
   endif
   
+  if (nargin == 1)
+    [nmeas, ncon] = __tito_dim__ (P, "h2syn");
+  endif
+  
   if (! is_real_scalar (nmeas))
-    error ("h2syn: second argument invalid");
+    error ("h2syn: second argument 'nmeas' invalid");
   endif
   
   if (! is_real_scalar (ncon))
-    error ("h2syn: third argument invalid");
+    error ("h2syn: third argument 'ncon' invalid");
   endif
 
   [a, b, c, d, tsam] = ssdata (P);
@@ -143,7 +150,11 @@ function [K, varargout] = h2syn (P, nmeas, ncon)
     N = lft (P, K);
     varargout{1} = N;
     if (nargout > 2)
-      varargout{2} = struct ("gamma", norm (N, 2), "rcond", rcond);
+      gamma = norm (N, 2);
+      varargout{2} = gamma;
+      if (nargout > 3)
+        varargout{3} = struct ("gamma", gamma, "rcond", rcond);
+      endif
     endif
   endif
 
@@ -261,4 +272,4 @@ endfunction
 %!
 %! M_exp = [KA, KB; KC, KD];
 %!
-%!assert (M, M_exp, 1e-4);
\ No newline at end of file
+%!assert (M, M_exp, 1e-4);
