@@ -1,4 +1,4 @@
-## Copyright (C) 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -22,15 +22,15 @@
 ## @deftypefnx{Function File} {[@var{Gr}, @var{info}] =} hnamodred (@var{G}, @var{nr}, @var{opt}, @dots{})
 ##
 ## Model order reduction by frequency weighted optimal Hankel-norm (HNA) method.
-## The aim of model reduction is to find an LTI system @var{Gr} of order
+## The aim of model reduction is to find an @acronym{LTI} system @var{Gr} of order
 ## @var{nr} (nr < n) such that the input-output behaviour of @var{Gr}
 ## approximates the one from original system @var{G}.
 ##
 ## HNA is an absolute error method which tries to minimize
 ## @iftex
 ## @tex
-## $$ || G - G_r ||_H = min $$
-## $$ || V \\ (G - G_r) \\ W ||_H = min $$
+## $$ || G - G_r ||_H = \\min $$
+## $$ || V \\ (G - G_r) \\ W ||_H = \\min $$
 ## @end tex
 ## @end iftex
 ## @ifnottex
@@ -48,7 +48,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item G
-## LTI model to be reduced.
+## @acronym{LTI} model to be reduced.
 ## @item nr
 ## The desired order of the resulting reduced order system @var{Gr}.
 ## If not specified, @var{nr} is chosen automatically according
@@ -108,10 +108,10 @@
 ##
 ##
 ## @item 'left', 'v'
-## LTI model of the left/output frequency weighting.
+## @acronym{LTI} model of the left/output frequency weighting.
 ## The weighting must be antistable.
 ## @iftex
-## @math{|| V \\ (G-G_r) \\dots ||_H = min}
+## @math{|| V \\ (G-G_r) \\dots ||_H = \\min}
 ## @end iftex
 ## @ifnottex
 ## @example
@@ -121,10 +121,10 @@
 ## @end ifnottex
 ##
 ## @item 'right', 'w'
-## LTI model of the right/input frequency weighting.
+## @acronym{LTI} model of the right/input frequency weighting.
 ## The weighting must be antistable.
 ## @iftex
-## @math{|| \\dots (G-G_r) \\ W ||_H = min}
+## @math{|| \\dots (G-G_r) \\ W ||_H = \\min}
 ## @end iftex
 ## @ifnottex
 ## @example
@@ -135,10 +135,10 @@
 ##
 ##
 ## @item 'left-inv', 'inv-v'
-## LTI model of the left/output frequency weighting.
+## @acronym{LTI} model of the left/output frequency weighting.
 ## The weighting must have only antistable zeros.
 ## @iftex
-## @math{|| inv(V) \\ (G-G_r) \\dots ||_H = min}
+## @math{|| inv(V) \\ (G-G_r) \\dots ||_H = \\min}
 ## @end iftex
 ## @ifnottex
 ## @example
@@ -148,10 +148,10 @@
 ## @end ifnottex
 ##
 ## @item 'right-inv', 'inv-w'
-## LTI model of the right/input frequency weighting.
+## @acronym{LTI} model of the right/input frequency weighting.
 ## The weighting must have only antistable zeros.
 ## @iftex
-## @math{|| \\dots (G-G_r) \\ inv(W) ||_H = min}
+## @math{|| \\dots (G-G_r) \\ inv(W) ||_H = \\min}
 ## @end iftex
 ## @ifnottex
 ## @example
@@ -162,10 +162,10 @@
 ##
 ##
 ## @item 'left-conj', 'conj-v'
-## LTI model of the left/output frequency weighting.
+## @acronym{LTI} model of the left/output frequency weighting.
 ## The weighting must be stable.
 ## @iftex
-## @math{|| conj(V) \\ (G-G_r) \\dots ||_H = min}
+## @math{|| conj(V) \\ (G-G_r) \\dots ||_H = \\min}
 ## @end iftex
 ## @ifnottex
 ## @example
@@ -175,10 +175,10 @@
 ## @end ifnottex
 ##
 ## @item 'right-conj', 'conj-w'
-## LTI model of the right/input frequency weighting.
+## @acronym{LTI} model of the right/input frequency weighting.
 ## The weighting must be stable.
 ## @iftex
-## @math{|| \\dots (G-G_r) \\ conj(W) ||_H = min}
+## @math{|| \\dots (G-G_r) \\ conj(W) ||_H = \\min}
 ## @end iftex
 ## @ifnottex
 ## @example
@@ -189,10 +189,10 @@
 ##
 ##
 ## @item 'left-conj-inv', 'conj-inv-v'
-## LTI model of the left/output frequency weighting.
+## @acronym{LTI} model of the left/output frequency weighting.
 ## The weighting must be minimum-phase.
 ## @iftex
-## @math{|| conj(inv(V)) \\ (G-G_r) \\dots ||_H = min}
+## @math{|| conj(inv(V)) \\ (G-G_r) \\dots ||_H = \\min}
 ## @end iftex
 ## @ifnottex
 ## @example
@@ -202,10 +202,10 @@
 ## @end ifnottex
 ##
 ## @item 'right-conj-inv', 'conj-inv-w'
-## LTI model of the right/input frequency weighting.
+## @acronym{LTI} model of the right/input frequency weighting.
 ## The weighting must be minimum-phase.
 ## @iftex
-## @math{|| \\dots (G-G_r) \\ conj(inv(W)) ||_H = min}
+## @math{|| \\dots (G-G_r) \\ conj(inv(W)) ||_H = \\min}
 ## @end iftex
 ## @ifnottex
 ## @example
@@ -394,9 +394,9 @@ function [Gr, info] = hnamodred (G, varargin)
 
   
   ## perform model order reduction
-  [ar, br, cr, dr, nr, hsv, ns] = __sl_ab09jd__ (a, b, c, d, dt, scaled, nr, ordsel, alpha, \
-                                            jobv, av, bv, cv, dv, \
-                                            jobw, aw, bw, cw, dw, \
+  [ar, br, cr, dr, nr, hsv, ns] = __sl_ab09jd__ (a, b, c, d, dt, scaled, nr, ordsel, alpha, ...
+                                            jobv, av, bv, cv, dv, ...
+                                            jobw, aw, bw, cw, dw, ...
                                             jobinv, tol1, tol2);
 
   ## assemble reduced order model
