@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2012   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -26,13 +26,13 @@
 ## @deftypefnx{Function File} {[@var{y}, @var{t}, @var{x}] =} impulse (@var{sys}, @var{t})
 ## @deftypefnx{Function File} {[@var{y}, @var{t}, @var{x}] =} impulse (@var{sys}, @var{tfinal})
 ## @deftypefnx{Function File} {[@var{y}, @var{t}, @var{x}] =} impulse (@var{sys}, @var{tfinal}, @var{dt})
-## Impulse response of LTI system.
+## Impulse response of @acronym{LTI} system.
 ## If no output arguments are given, the response is printed on the screen.
 ##
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI model.
+## @acronym{LTI} model.
 ## @item t
 ## Time vector.  Should be evenly spaced.  If not specified, it is calculated by
 ## the poles of the system to reflect adequately the response transients.
