@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2013   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -29,7 +29,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI model.  Descriptor state-space models are possible.
+## @acronym{LTI} model.  Descriptor state-space models are possible.
 ## If @var{sys} is not a state-space model, it is converted to
 ## a minimal state-space realization, so beware of pole-zero
 ## cancellations which may lead to wrong results!
