@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -32,7 +32,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI system.
+## @acronym{LTI} system.
 ## @item a
 ## State transition matrix.
 ## @item c
@@ -84,4 +84,3 @@ function bool = isdetectable (a, c = [], e = [], tol = [], dflg = 0)
   endif
 
 endfunction
-
