@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2012, 2013   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -32,7 +32,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI system.  If @var{sys} is not a state-space system, it is converted to
+## @acronym{LTI} system.  If @var{sys} is not a state-space system, it is converted to
 ## a minimal state-space realization, so beware of pole-zero cancellations
 ## which may lead to wrong results!
 ## @item a
