@@ -1,5 +1,5 @@
-## Copyright (C) 2012   Lukas F. Reichlin
-## Copyright (C) 2012   Megan Zagrobelny
+## Copyright (C) 2009-2014   Lukas F. Reichlin
+## Copyright (C) 2012        Megan Zagrobelny
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -37,7 +37,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## Continuous or discrete-time LTI model (p-by-m, n states).
+## Continuous or discrete-time @acronym{LTI} model (p-by-m, n states).
 ## @item a
 ## State matrix of continuous-time system (n-by-n).
 ## @item g
@@ -94,12 +94,12 @@ function [l, p, e] = lqe (a, g, c, q = [], r = [], s = [])
   elseif (isempty (g))
     [l, p, e] = lqr (a.', c.', q, r, s);    # lqe (a, [], c, q, r, s), g=I, works like  lqr (a.', c.', q, r, s).'
   elseif (columns (g) != rows (q) || ! issquare (q))
-    error ("lqe: matrices g(%dx%d) and q(%dx%d) have incompatible dimensions", \
+    error ("lqe: matrices g(%dx%d) and q(%dx%d) have incompatible dimensions", ...
             rows (g), columns (g), rows (q), columns (q));
   elseif (isempty (s))
     [l, p, e] = lqr (a.', c.', g*q*g.', r);
   elseif (columns (g) != rows (s))
-    error ("lqe: matrices g(%dx%d) and s(%dx%d) have incompatible dimensions", \
+    error ("lqe: matrices g(%dx%d) and s(%dx%d) have incompatible dimensions", ...
             rows (g), columns (g), rows (s), columns (s));
   else
     [l, p, e] = lqr (a.', c.', g*q*g.', r, g*s);
