@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -27,7 +27,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## Continuous or discrete-time LTI model (p-by-m, n states).
+## Continuous or discrete-time @acronym{LTI} model (p-by-m, n states).
 ## @item a
 ## State matrix of continuous-time system (n-by-n).
 ## @item b
@@ -95,4 +95,4 @@ function [g, x, l] = lqr (a, b, q, r = [], s = [], e = [])
     [x, l, g] = care (a, b, q, r, s, e);
   endif
 
-endfunction
\ No newline at end of file
+endfunction
