@@ -1,5 +1,5 @@
 ## Copyright (C) 2009 Luca Favatella
-## Copyright (C) 2009, 2010, 2011   Lukas Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -20,7 +20,7 @@
 ## @deftypefn {Function File} test ltimodels
 ## @deftypefnx {Function File} ltimodels
 ## @deftypefnx {Function File} ltimodels (@var{systype})
-## Test suite and help for LTI models.
+## Test suite and help for @acronym{LTI} models.
 ## @end deftypefn
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
@@ -43,18 +43,18 @@ function ltimodels (systype = "general")
 
   switch (systype)
     case "ss"
-      str = {"State Space (SS) Models"\
-             "-----------------------"\
+      str = {"State Space (SS) Models"...
+             "-----------------------"...
              ""};
 
     case "tf"
-      str = {"Transfer Function (TF) Models"\
-             "-----------------------------"\
+      str = {"Transfer Function (TF) Models"...
+             "-----------------------------"...
              ""};
 
     otherwise  # general
-      str = {"Linear Time Invariant (LTI) Models"\
-             "----------------------------------"\
+      str = {"Linear Time Invariant (LTI) Models"...
+             "----------------------------------"...
              ""};
 
   endswitch
