@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2013   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -16,7 +16,7 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn{Function File} {[@var{K}, @var{N}, @var{info}] =} mixsyn (@var{G}, @var{W1}, @var{W2}, @var{W3}, @dots{})
+## @deftypefn{Function File} {[@var{K}, @var{N}, @var{gamma}, @var{info}] =} mixsyn (@var{G}, @var{W1}, @var{W2}, @var{W3}, @dots{})
 ## Solve stacked S/KS/T H-infinity problem.
 ## Mixed-sensitivity is the name given to transfer function shaping problems in which
 ## the sensitivity function
@@ -171,7 +171,7 @@
 ## integral action, 
 ## @iftex
 ## @tex
-## $\\frac{1}{s}$
+## ${1 \\over s}$
 ## @end tex
 ## @end iftex
 ## @ifnottex
@@ -184,7 +184,7 @@
 ## needs to be approximated by
 ## @iftex
 ## @tex
-## $\\frac{1}{s + \\epsilon}$, where $\\epsilon \\ll 1$.
+## ${1 \\over s + \\epsilon}$, where $\\epsilon \\ll 1$.
 ## @end tex
 ## @end iftex
 ## @ifnottex
@@ -199,7 +199,7 @@
 ## The trick here is to replace a non-proper term such as
 ## @iftex
 ## @tex
-## $ 1 + \\tau_1 s $ by $ \\frac{1 + \\tau_1 s}{1 + \\tau_2 s} $, where
+## $ 1 + \\tau_1 s $ by $ {1 + \\tau_1 s \\over 1 + \\tau_2 s} $, where
 ## @end tex
 ## @end iftex
 ## @ifnottex
@@ -220,22 +220,22 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item G
-## LTI model of plant.
+## @acronym{LTI} model of plant.
 ## @item W1
-## LTI model of performance weight.  Bounds the largest singular values of sensitivity @var{S}.
+## @acronym{LTI} model of performance weight.  Bounds the largest singular values of sensitivity @var{S}.
 ## Model must be empty @code{[]}, SISO or of appropriate size.
 ## @item W2
-## LTI model to penalize large control inputs.  Bounds the largest singular values of @var{KS}.
+## @acronym{LTI} model to penalize large control inputs.  Bounds the largest singular values of @var{KS}.
 ## Model must be empty @code{[]}, SISO or of appropriate size.
 ## @item W3
-## LTI model of robustness and noise sensitivity weight.  Bounds the largest singular values of 
+## @acronym{LTI} model of robustness and noise sensitivity weight.  Bounds the largest singular values of 
 ## complementary sensitivity @var{T}.  Model must be empty @code{[]}, SISO or of appropriate size.
 ## @item @dots{}
 ## Optional arguments of @command{hinfsyn}.  Type @command{help hinfsyn} for more information.
 ## @end table
 ##
 ## All inputs must be proper/realizable.
-## Scalars, vectors and matrices are possible instead of LTI models.
+## Scalars, vectors and matrices are possible instead of @acronym{LTI} models.
 ##
 ## @strong{Outputs}
 ## @table @var
@@ -321,8 +321,8 @@
 ## @end example
 ##
 ## @strong{Algorithm}@*
-## Relies on commands @command{augw} and @command{hinfsyn},
-## which use SLICOT SB10FD and SB10DD by courtesy of
+## Relies on functions @command{augw} and @command{hinfsyn},
+## which use SLICOT SB10FD, SB10DD and SB10AD by courtesy of
 ## @uref{http://www.slicot.org, NICONET e.V.}
 ##
 ## @strong{References}@*
@@ -340,7 +340,7 @@
 ## Created: December 2009
 ## Version: 0.2
 
-function [K, N, info] = mixsyn (G, W1 = [], W2 = [], W3 = [], varargin)
+function [K, N, gamma, info] = mixsyn (G, W1 = [], W2 = [], W3 = [], varargin)
 
   if (nargin == 0)
     print_usage ();
@@ -350,6 +350,6 @@ function [K, N, info] = mixsyn (G, W1 = [], W2 = [], W3 = [], varargin)
 
   P = augw (G, W1, W2, W3);
   
-  [K, N, info] = hinfsyn (P, p, m, varargin{:});
+  [K, N, gamma, info] = hinfsyn (P, p, m, varargin{:});
 
 endfunction
