@@ -1,4 +1,4 @@
-## Copyright (C) 2011, 2013   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -16,7 +16,7 @@
 ## along with LTI Syncope.  If not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn{Function File} {[@var{K}, @var{N}, @var{info}] =} ncfsyn (@var{G}, @var{W1}, @var{W2}, @var{factor})
+## @deftypefn{Function File} {[@var{K}, @var{N}, @var{gamma}, @var{info}] =} ncfsyn (@var{G}, @var{W1}, @var{W2}, @var{factor})
 ## Loop shaping H-infinity synthesis.  Compute positive feedback controller using 
 ## the McFarlane/Glover loop shaping design procedure [1].
 ## Using a precompensator @var{W1} and/or a postcompensator @var{W2}, the singular values
@@ -196,13 +196,13 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item G
-## LTI model of plant.
+## @acronym{LTI} model of plant.
 ## @item W1
-## LTI model of precompensator.  Model must be SISO or of appropriate size.
+## @acronym{LTI} model of precompensator.  Model must be SISO or of appropriate size.
 ## An identity matrix is taken if @var{W1} is not specified or if an empty model
 ## @code{[]} is passed.
 ## @item W2
-## LTI model of postcompensator.  Model must be SISO or of appropriate size.
+## @acronym{LTI} model of postcompensator.  Model must be SISO or of appropriate size.
 ## An identity matrix is taken if @var{W2} is not specified or if an empty model
 ## @code{[]} is passed.
 ## @item factor
@@ -216,6 +216,7 @@
 ## @table @var
 ## @item K
 ## State-space model of the H-infinity loop-shaping controller.
+## Note that @var{K} is a @emph{positive} feedback controller.
 ## @item N
 ## State-space model of the closed loop depicted below.
 ## @item info
@@ -316,7 +317,10 @@ function [K, varargout] = ncfsyn (G, W1 = [], W2 = [], factor = 1.0)
     varargout{1} = N;
     if (nargout > 2)
       gamma = norm (N, inf);
-      varargout{2} = struct ("gamma", gamma, "emax", inv (gamma), "Gs", Gs, "Ks", Ks, "rcond", rcond);
+      varargout{2} = gamma;
+      if (nargout > 3)
+        varargout{3} = struct ("gamma", gamma, "emax", inv (gamma), "Gs", Gs, "Ks", Ks, "rcond", rcond);
+      endif
     endif
   endif
 
