@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2011, 2012   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -39,14 +39,16 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: May 2010
-## Version: 0.4
+## Version: 0.5
 
 ## test collection
 test ltimodels
 
 ## LTI methods
 test @lti/c2d
+test @lti/connect
 test @lti/d2c
+test @lti/d2d
 test @lti/feedback
 test @lti/horzcat
 test @lti/inv
@@ -89,26 +91,28 @@ test cfconred
 test fwcfconred
 ## test spaconred  # TODO: create test case
 
-## identification
-test fitfrd
-
 ## various oct-files
 test ctrbf
 test hsvd
 test place
 
 ## various m-files
+test db2mag
 test ctrb
 test filt
 test initial
 test issample
+test mag2db
 test margin
 test obsv
 test sigma
+test thiran
+test __dss2ss__
 
 ## identification
 test @iddata/iddata
 test @iddata/cat
 test @iddata/detrend
 test @iddata/fft
+test fitfrd
 test moen4
