@@ -1,4 +1,4 @@
-## Copyright (C) 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -30,7 +30,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## LTI model to be converted to transfer function.
+## @acronym{LTI} model to be converted to transfer function.
 ## @item z
 ## Cell of vectors containing the zeros for each channel.
 ## z@{i,j@} contains the zeros from input j to output i.
@@ -102,4 +102,3 @@ function sys = zpk (z = {}, p = {}, k = [], varargin)
   endswitch
 
 endfunction
-
