@@ -43,6 +43,8 @@
 #include "sl_ib01cd.cc"  // compute initial state vector
 #include "sl_ib01ad.cc"  // compute singular values
 // #include "sl_are.cc"     // solve ARE with Schur vector approach and scaling
+#include "sl_tg01fd.cc"  // orthogonal reduction of dss to a SVD-like coordinate form
+#include "sl_sb10ad.cc"  // H-infinity optimal controller using modified Glover's and Doyle's formulas (continuous-time)
 
 
 // stub function to avoid gen_doc_cache warning upon package installation
